@@ -6,13 +6,13 @@ runExample("simple")
 
 ## Run RWM and two gradient based algorithms, using adative step size (eps)
 ## for each. Start from the MLE.
-rwm <- mcmc(obj=obj, nsim=500*8, algorithm='RWM', params.init=opt$par,
+rwm <- run_mcmc(obj=obj, nsim=500*8, algorithm='RWM', params.init=opt$par,
             alpha=.08, diagnostic=TRUE)
 ## Thin it to better approximate the gradient methods
 rwm$par <- rwm$par[seq(1, nrow(rwm$par), by=8),]
-hmc <- mcmc(obj=obj, nsim=500, algorithm='HMC', L=8, params.init=opt$par,
+hmc <- run_mcmc(obj=obj, nsim=500, algorithm='HMC', L=8, params.init=opt$par,
             diagnostic=TRUE, eps=0.1)
-nuts <- mcmc(obj=obj, nsim=500, algorithm='NUTS', params.init=opt$par,
+nuts <- run_mcmc(obj=obj, nsim=500, algorithm='NUTS', params.init=opt$par,
              diagnostic=TRUE, eps=0.1)
 
 ## See how they compare via ACF
